import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../bloc/loadable_state_bloc.dart';

class LoadableStateErrorBar extends StatelessWidget {
  final bool visible;
  const LoadableStateErrorBar({required this.visible, super.key});

  final Duration animationDuration = const Duration(milliseconds: 200);

  @override
  Widget build(BuildContext context) => AnimatedSize(
    duration: animationDuration,
    child: AnimatedSwitcher(
        duration: animationDuration,
        transitionBuilder: (Widget child, Animation<double> animation) => SlideTransition(
          position: Tween<Offset>(
            begin: const Offset(0.0, -1.0),
            end: Offset.zero,
          ).animate(animation),
          child: child,
        ),
        child: Visibility(
            key: Key(visible.hashCode.toString()),
            visible: visible,
            replacement: const SizedBox(width: double.infinity),
            child: Builder(
              builder: (context) {
                var bloc = context.watch<LoadableStateBloc>();
                var status = (
                icon: bloc.connectionIcon(),
                text: bloc.connectionText(),
                color: bloc.connectivityStatusKnown() && !bloc.isConnected()
                    ? Colors.grey.shade600
                    : Theme.of(context).primaryColor
                );

                return Container(
                  height: 20,
                  decoration: BoxDecoration(
                    color: status.color,
                  ),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Icon(status.icon, size: 14),
                      const SizedBox(width: 10),
                      Text(status.text, style: const TextStyle(fontSize: 12))
                    ],
                  ),
                );
              },
            )
        )
    ),
  );
}
