import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../bloc/loadable_state_bloc.dart';
import 'loadable_state_consumer.dart';

class LoadableStateErrorScreen extends StatelessWidget {
  final bool visible;
  const LoadableStateErrorScreen({required this.visible, super.key});


  @override
  Widget build(BuildContext context) {
    final bloc = context.watch<LoadableStateBloc>();
    return AnimatedOpacity(
      opacity: visible ? 1.0 : 0.0,
      duration: LoadableStateConsumer.animationDuration,
      curve: Curves.easeInOut,
      child: !visible ? null : Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Icon(bloc.connectionIcon(), size: 40),
            const SizedBox(height: 10),
            Text(bloc.connectionText(), style: const TextStyle(fontSize: 20)),

            if(bloc.allowRetry()) ...[
              const SizedBox(height: 10),
              TextButton(onPressed: () => bloc.reFetch!(), child: const Text('Erneut versuschen')),
            ],

            if(bloc.showErrorMessage()) ...[
              const SizedBox(height: 40),
              Text("bloc.loadingError!.message", style: TextStyle(color: Theme.of(context).hintColor, fontSize: 12))
            ],
          ],
        ),
      ),
    );
  }
}
